@@ -3,9 +3,9 @@ context('Test parameters calculations.')
 test_that('Test click calcs', {
     data(testClick)
     clickData <- standardClickCalcs(testClick)
-    expect_true(all(c('Channel', 'peak', 'peak2', 'Q_10dB') %in% colnames(clickData)))
+    expect_true(all(c('peak', 'peak2', 'Q_10dB') %in% colnames(clickData)))
     expect_is(clickData, 'data.frame')
-    expect_equal(ncol(clickData), 23)
+    expect_equal(ncol(clickData), 22)
     expect_equal(nrow(clickData), 2)
     expect_true(!any(is.na(clickData)))
     expect_true(clickChecker(standardClickCalcs))
